@@ -8,6 +8,8 @@
 #include "viewslistdata.h"
 #include "viewconfigurationdata.h"
 
+#include "elisa_settings.h"
+
 #include <QtTest>
 
 class ViewManagerTests: public QObject
@@ -37,10 +39,13 @@ private Q_SLOTS:
         qRegisterMetaType<QAbstractItemModel*>("QAbstractItemModel*");
         qRegisterMetaType<QAbstractProxyModel*>("QAbstractProxyModel*");
         qRegisterMetaType<DataTypes::DataType>("DataTypes::DataType");
+        QStandardPaths::setTestModeEnabled(true);
+        Elisa::ElisaConfiguration::instance(QStringLiteral("testfoo"));
     }
 
     void openAlbumViewTest()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -50,6 +55,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openChildView({{DataTypes::TitleRole, QStringLiteral("album1")},
                                    {DataTypes::ArtistRole, QStringLiteral("artist1")},
                                    {DataTypes::DatabaseIdRole, 12},
@@ -85,6 +97,7 @@ private Q_SLOTS:
 
     void openAlbumView2Test()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -94,6 +107,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(3);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -175,6 +195,7 @@ private Q_SLOTS:
 
     void openAlbumView3Test()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -184,6 +205,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(3);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -261,6 +289,7 @@ private Q_SLOTS:
 
     void openArtistViewTest()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -270,6 +299,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openChildView({{DataTypes::TitleRole, QStringLiteral("artist1")},
                                    {DataTypes::DatabaseIdRole, 12},
                                    {DataTypes::ElementTypeRole, ElisaUtils::Artist}});
@@ -305,6 +341,7 @@ private Q_SLOTS:
 
     void openArtistView2Test()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -314,6 +351,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(4);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -395,6 +439,7 @@ private Q_SLOTS:
 
     void openArtistView3Test()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -404,6 +449,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(4);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -481,6 +533,7 @@ private Q_SLOTS:
 
     void openGenreViewTest()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -490,6 +543,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openChildView({{DataTypes::TitleRole, QStringLiteral("genre1")},
                                    {DataTypes::DatabaseIdRole, 12},
                                    {DataTypes::ElementTypeRole, ElisaUtils::Genre}});
@@ -525,6 +585,7 @@ private Q_SLOTS:
 
     void openGenreView2Test()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -534,6 +595,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(6);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -615,6 +683,7 @@ private Q_SLOTS:
 
     void openGenreView3Test()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -624,6 +693,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(6);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -701,6 +777,7 @@ private Q_SLOTS:
 
     void openArtistFromGenreViewTest()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -710,6 +787,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openView(6);
 
         QCOMPARE(openGridViewSpy.count(), 1);
@@ -769,6 +853,7 @@ private Q_SLOTS:
 
     void openArtistViewAndAlbumFromAnotherArtistTest()
     {
+        Elisa::ElisaConfiguration::self()->setDefaults();
         ViewManager viewManager;
         ViewsListData viewsData;
         viewManager.setViewsData(&viewsData);
@@ -778,6 +863,13 @@ private Q_SLOTS:
         QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
         QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
 
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
         viewManager.openChildView({{DataTypes::TitleRole, QStringLiteral("artist1")},
                                    {DataTypes::DatabaseIdRole, 12},
                                    {DataTypes::ElementTypeRole, ElisaUtils::Artist}});
@@ -845,6 +937,70 @@ private Q_SLOTS:
         QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
         QCOMPARE(popOneViewSpy.count(), 0);
     }
+
+    void openNowPlayingViewTest()
+    {
+        Elisa::ElisaConfiguration::self()->setDefaults();
+        ViewManager viewManager;
+        ViewsListData viewsData;
+        viewManager.setViewsData(&viewsData);
+
+        QSignalSpy openGridViewSpy(&viewManager, &ViewManager::openGridView);
+        QSignalSpy openListViewSpy(&viewManager, &ViewManager::openListView);
+        QSignalSpy switchFilesBrowserViewSpy(&viewManager, &ViewManager::switchFilesBrowserView);
+        QSignalSpy switchContextViewSpy(&viewManager, &ViewManager::switchContextView);
+        QSignalSpy popOneViewSpy(&viewManager, &ViewManager::popOneView);
+
+        viewManager.setInitialIndex(0);
+
+        QCOMPARE(openGridViewSpy.count(), 0);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(switchContextViewSpy.count(), 1);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
+        viewManager.openChildView({{DataTypes::TitleRole, QStringLiteral("album1")},
+                                   {DataTypes::ArtistRole, QStringLiteral("artist1")},
+                                   {DataTypes::DatabaseIdRole, 12},
+                                   {DataTypes::ElementTypeRole, ElisaUtils::Album}});
+
+        QCOMPARE(openGridViewSpy.count(), 1);
+        QCOMPARE(switchContextViewSpy.count(), 1);
+        QCOMPARE(openListViewSpy.count(), 0);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
+        QCOMPARE(openGridViewSpy.at(0).count(), 1);
+        QCOMPARE(openGridViewSpy.at(0).at(0).value<ViewConfigurationData*>()->filterType(), ElisaUtils::NoFilter);
+        QCOMPARE(openGridViewSpy.at(0).at(0).value<ViewConfigurationData*>()->dataType(), ElisaUtils::Album);
+
+        viewManager.viewIsLoaded();
+
+        QCOMPARE(openGridViewSpy.count(), 1);
+        QCOMPARE(openListViewSpy.count(), 1);
+        QCOMPARE(switchContextViewSpy.count(), 1);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
+        QCOMPARE(openListViewSpy.at(0).count(), 1);
+        QCOMPARE(openListViewSpy.at(0).at(0).value<ViewConfigurationData*>()->dataFilter()[DataTypes::TitleRole].toString(), QStringLiteral("album1"));
+        QCOMPARE(openListViewSpy.at(0).at(0).value<ViewConfigurationData*>()->dataFilter()[DataTypes::ArtistRole].toString(), QStringLiteral("artist1"));
+
+        viewManager.viewIsLoaded();
+
+        QCOMPARE(openGridViewSpy.count(), 1);
+        QCOMPARE(openListViewSpy.count(), 1);
+        QCOMPARE(switchContextViewSpy.count(), 1);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+
+        viewManager.openNowPlaying();
+        QCOMPARE(openGridViewSpy.count(), 1);
+        QCOMPARE(openListViewSpy.count(), 1);
+        QCOMPARE(switchContextViewSpy.count(), 2);
+        QCOMPARE(switchFilesBrowserViewSpy.count(), 0);
+        QCOMPARE(popOneViewSpy.count(), 0);
+    }
 };
 
 QTEST_GUILESS_MAIN(ViewManagerTests)
